@@ -24,7 +24,7 @@ class ADependency(event.AReactive, metaclass=abstracts.Abstraction):
             self,
             id: str,
             metadata: "typing.DependencyMetadataDict",
-            github: github.AGithubAPI,
+            github: github.IGithubAPI,
             loop: Optional[asyncio.AbstractEventLoop] = None,
             pool: Optional[futures.Executor] = None) -> None:
         self.id = id
@@ -129,7 +129,7 @@ class ADependency(event.AReactive, metaclass=abstracts.Abstraction):
             self.release_class(
                 self.repo,
                 newer_release.tag_name,
-                release=newer_release)
+                release=newer_release)  # type:ignore
             if (newer_release
                 and (version.parse(newer_release.tag_name)
                      != self.release.version))
@@ -202,9 +202,10 @@ class ADependency(event.AReactive, metaclass=abstracts.Abstraction):
             return None
 
     @cached_property
-    def repo(self) -> github.AGithubRepo:
+    def repo(self) -> github.IGithubRepo:
         """Github repo for this dependency."""
-        return self.github[f"{self.organization}/{self.project}"]
+        return self.github[
+            f"{self.organization}/{self.project}"]  # type: ignore
 
     @cached_property
     def url_components(self) -> List[str]:
